@@ -666,6 +666,23 @@ class TestWizard(test.TestCase):
         wiz.handle_request(self.mock_request, 'first')
         send_postdisplay.assert_called_once_with(wiz, step_key='first')
 
+    @mock.patch('wizard.signals.wizard_prereq.send')
+    def test_sends_prereq_signal_in_handle_prereq(self, send_prereq):
+        wiz = wizard.Wizard('test:test3', self.steps)
+        wiz.steps = dict(self.steps)
+        wiz.handle_prereq('fourth')
+        send_prereq.assert_called_once_with(wiz, step_key='fourth')
+
+    @mock.patch('wizard.signals.wizard_prereq.send')
+    def test_prereq_exceptions_are_caught_when_raised_by_prereq_signal(self, send_prereq):
+        send_prereq.side_effect = lambda *args, **kwargs:(e for e in [wizard.PrereqMissing])
+        wiz = wizard.Wizard('test:test3', self.steps)
+        wiz.steps = dict(self.steps)
+        try:
+            wiz.handle_prereq('fourth')
+        except wizard.PrereqMissing:
+            self.fail("Prereq should not have been raised")
+
     def test_request_is_none_before_handle_request(self):
         wiz = wizard.Wizard('test:test3', self.steps)
         self.assertEqual(None, wiz.request)
